@@ -96,7 +96,7 @@ if sys.platform != "win32":
         view = memoryview(buf)
         sent = 0
 
-        def _is_ready(fut: Future) -> None:
+        def _is_ready(fut: Future[Any]) -> None:
             if fut.done():
                 return
             fut.set_result(None)
@@ -139,7 +139,7 @@ if sys.platform != "win32":
         mv = memoryview(bytearray(length))
         total_read = 0
 
-        def _is_ready(fut: Future) -> None:
+        def _is_ready(fut: Future[Any]) -> None:
             if fut.done():
                 return
             fut.set_result(None)
@@ -465,7 +465,7 @@ class NetworkingInterface(NetworkingInterfaceBase):
     def fileno(self) -> int:
         return self.conn.fileno()
 
-    def recv_into(self, buffer: bytes) -> int:
+    def recv_into(self, buffer: bytes | memoryview) -> int:
         return self.conn.recv_into(buffer)
 
 
@@ -486,15 +486,15 @@ class PyMongoProtocol(BufferedProtocol):
         self._message_size = 0
         self._op_code = 0
         self._connection_lost = False
-        self._read_waiter: Optional[Future] = None
+        self._read_waiter: Optional[Future[Any]] = None
         self._timeout = timeout
         self._is_compressed = False
         self._compressor_id: Optional[int] = None
         self._max_message_size = MAX_MESSAGE_SIZE
         self._response_to: Optional[int] = None
         self._closed = asyncio.get_running_loop().create_future()
-        self._pending_messages: collections.deque[Future] = collections.deque()
-        self._done_messages: collections.deque[Future] = collections.deque()
+        self._pending_messages: collections.deque[Future[Any]] = collections.deque()
+        self._done_messages: collections.deque[Future[Any]] = collections.deque()
 
     def settimeout(self, timeout: float | None) -> None:
         self._timeout = timeout
@@ -770,6 +770,7 @@ def receive_message(
             f"Message length ({length!r}) is larger than server max "
             f"message size ({max_message_size!r})"
         )
+    data: memoryview | bytes
     if op_code == 2012:
         op_code, _, compressor_id = _UNPACK_COMPRESSION_HEADER(receive_data(conn, 9, deadline))
         data = decompress(receive_data(conn, length - 25, deadline), compressor_id)
