@@ -138,10 +138,9 @@ class Cursor(Generic[_DocumentType]):
 
         if session:
             self._session = session
-            self._explicit_session = True
+            self._session._attached_to_cursor = True
         else:
             self._session = None
-            self._explicit_session = False
 
         spec: Mapping[str, Any] = filter or {}
         validate_is_mapping("filter", spec)
@@ -150,7 +149,7 @@ class Cursor(Generic[_DocumentType]):
         if not isinstance(limit, int):
             raise TypeError(f"limit must be an instance of int, not {type(limit)}")
         validate_boolean("no_cursor_timeout", no_cursor_timeout)
-        if no_cursor_timeout and not self._explicit_session:
+        if no_cursor_timeout and self._session and self._session._implicit:
             warnings.warn(
                 "use an explicit session with no_cursor_timeout=True "
                 "otherwise the cursor may still timeout after "
@@ -283,7 +282,7 @@ class Cursor(Generic[_DocumentType]):
     def _clone(self, deepcopy: bool = True, base: Optional[Cursor] = None) -> Cursor:  # type: ignore[type-arg]
         """Internal clone helper."""
         if not base:
-            if self._explicit_session:
+            if self._session and not self._session._implicit:
                 base = self._clone_base(self._session)
             else:
                 base = self._clone_base(None)
@@ -943,7 +942,7 @@ class Cursor(Generic[_DocumentType]):
 
         .. versionadded:: 3.6
         """
-        if self._explicit_session:
+        if self._session and not self._session._implicit:
             return self._session
         return None
 
@@ -1032,9 +1031,10 @@ class Cursor(Generic[_DocumentType]):
 
         cursor_id, address = self._prepare_to_die(already_killed)
         self._collection.database.client._cleanup_cursor_no_lock(
-            cursor_id, address, self._sock_mgr, self._session, self._explicit_session
+            cursor_id, address, self._sock_mgr, self._session
         )
-        if not self._explicit_session:
+        if self._session and self._session._implicit:
+            self._session._attached_to_cursor = False
             self._session = None
         self._sock_mgr = None
 
@@ -1052,9 +1052,9 @@ class Cursor(Generic[_DocumentType]):
             address,
             self._sock_mgr,
             self._session,
-            self._explicit_session,
         )
-        if not self._explicit_session:
+        if self._session and self._session._implicit:
+            self._session._attached_to_cursor = False
             self._session = None
         self._sock_mgr = None
 
@@ -1062,7 +1062,7 @@ class Cursor(Generic[_DocumentType]):
         """Explicitly close / kill this cursor."""
         self._die_lock()
 
-    def distinct(self, key: str) -> list[str]:
+    def distinct(self, key: str) -> list[Any]:
         """Get a list of distinct values for `key` among all documents
         in the result set of this query.
 
