@@ -25,6 +25,7 @@ from test.asynchronous.utils import async_get_pool, async_is_mongos
 from typing import Any, Iterable, no_type_check
 
 from pymongo.asynchronous.database import AsyncDatabase
+from pymongo.asynchronous.helpers import anext
 
 sys.path[0:0] = [""]
 
@@ -40,6 +41,7 @@ from test.utils_shared import (
     OvertCommandListener,
     async_wait_until,
 )
+from test.version import Version
 
 from bson import encode
 from bson.codec_options import CodecOptions
@@ -50,7 +52,6 @@ from bson.son import SON
 from pymongo import ASCENDING, DESCENDING, GEO2D, GEOSPHERE, HASHED, TEXT
 from pymongo.asynchronous.collection import AsyncCollection, ReturnDocument
 from pymongo.asynchronous.command_cursor import AsyncCommandCursor
-from pymongo.asynchronous.helpers import anext
 from pymongo.asynchronous.mongo_client import AsyncMongoClient
 from pymongo.bulk_shared import BulkWriteError
 from pymongo.cursor_shared import CursorType
@@ -335,8 +336,6 @@ class AsyncTestCollection(AsyncIntegrationTest):
         await db.test.create_index(["hello", ("world", DESCENDING)])
         await db.test.create_index({"hello": 1}.items())  # type:ignore[arg-type]
 
-    # TODO: PYTHON-5491 - remove version max
-    @async_client_context.require_version_max(8, 0, -1)
     async def test_drop_index(self):
         db = self.db
         await db.test.drop_indexes()
@@ -348,7 +347,10 @@ class AsyncTestCollection(AsyncIntegrationTest):
         await db.test.drop_index(name)
 
         # Drop it again.
-        with self.assertRaises(OperationFailure):
+        if async_client_context.version < Version(8, 3, -1):
+            with self.assertRaises(OperationFailure):
+                await db.test.drop_index(name)
+        else:
             await db.test.drop_index(name)
         self.assertEqual(len(await db.test.index_information()), 2)
         self.assertIn("hello_1", await db.test.index_information())
@@ -1319,7 +1321,7 @@ class AsyncTestCollection(AsyncIntegrationTest):
             self.assertIn(exc.code, (9, 10147, 16840, 17009))
             # Just check that we set the error document. Fields
             # vary by MongoDB version.
-            self.assertTrue(exc.details is not None)
+            self.assertIsNotNone(exc.details)
         else:
             self.fail("OperationFailure was not raised")
 
