@@ -24,6 +24,7 @@ import time
 from asyncio import StreamReader, StreamWriter
 from pathlib import Path
 from test.asynchronous.helpers import ConcurrentRunner
+from test.asynchronous.utils import flaky
 
 from pymongo.asynchronous.pool import AsyncConnection
 from pymongo.operations import _Op
@@ -39,7 +40,7 @@ from test.asynchronous import (
     unittest,
 )
 from test.asynchronous.pymongo_mocks import DummyMonitor
-from test.asynchronous.unified_format import generate_test_classes
+from test.asynchronous.unified_format import generate_test_classes, get_test_path
 from test.asynchronous.utils import (
     async_get_pool,
 )
@@ -75,14 +76,7 @@ from pymongo.topology_description import TOPOLOGY_TYPE
 
 _IS_SYNC = False
 
-# Location of JSON test specifications.
-if _IS_SYNC:
-    SDAM_PATH = os.path.join(Path(__file__).resolve().parent, "discovery_and_monitoring")
-else:
-    SDAM_PATH = os.path.join(
-        Path(__file__).resolve().parent.parent,
-        "discovery_and_monitoring",
-    )
+SDAM_PATH = get_test_path("discovery_and_monitoring")
 
 
 async def create_mock_topology(uri, monitor_class=DummyMonitor):
@@ -90,8 +84,8 @@ async def create_mock_topology(uri, monitor_class=DummyMonitor):
     replica_set_name = None
     direct_connection = None
     load_balanced = None
-    if "replicaset" in parsed_uri["options"]:
-        replica_set_name = parsed_uri["options"]["replicaset"]
+    if "replicaSet" in parsed_uri["options"]:
+        replica_set_name = parsed_uri["options"]["replicaSet"]
     if "directConnection" in parsed_uri["options"]:
         direct_connection = parsed_uri["options"]["directConnection"]
     if "loadBalanced" in parsed_uri["options"]:
@@ -378,6 +372,7 @@ class TestPoolManagement(AsyncIntegrationTest):
     @async_client_context.require_failCommand_appName
     @async_client_context.require_test_commands
     @async_client_context.require_async
+    @flaky(reason="PYTHON-5428")
     async def test_connection_close_does_not_block_other_operations(self):
         listener = CMAPHeartbeatListener()
         client = await self.async_single_client(
@@ -445,7 +440,6 @@ class TestPoolManagement(AsyncIntegrationTest):
 
 
 class TestServerMonitoringMode(AsyncIntegrationTest):
-    @async_client_context.require_no_serverless
     @async_client_context.require_no_load_balancer
     async def asyncSetUp(self):
         await super().asyncSetUp()
@@ -484,7 +478,7 @@ class TestServerMonitoringMode(AsyncIntegrationTest):
 
     async def test_rtt_connection_is_disabled_auto(self):
         envs = [
-            {"AWS_EXECUTION_ENV": "AWS_Lambda_python3.9"},
+            {"AWS_EXECUTION_ENV": "AWS_Lambda_python3.10"},
             {"FUNCTIONS_WORKER_RUNTIME": "python"},
             {"K_SERVICE": "gcpservicename"},
             {"FUNCTION_NAME": "gcpfunctionname"},
