@@ -25,6 +25,7 @@ from test.utils import get_pool, is_mongos
 from typing import Any, Iterable, no_type_check
 
 from pymongo.synchronous.database import Database
+from pymongo.synchronous.helpers import next
 
 sys.path[0:0] = [""]
 
@@ -40,6 +41,7 @@ from test.utils_shared import (
     OvertCommandListener,
     wait_until,
 )
+from test.version import Version
 
 from bson import encode
 from bson.codec_options import CodecOptions
@@ -73,7 +75,6 @@ from pymongo.results import (
 )
 from pymongo.synchronous.collection import Collection, ReturnDocument
 from pymongo.synchronous.command_cursor import CommandCursor
-from pymongo.synchronous.helpers import next
 from pymongo.synchronous.mongo_client import MongoClient
 from pymongo.write_concern import WriteConcern
 
@@ -333,8 +334,6 @@ class TestCollection(IntegrationTest):
         db.test.create_index(["hello", ("world", DESCENDING)])
         db.test.create_index({"hello": 1}.items())  # type:ignore[arg-type]
 
-    # TODO: PYTHON-5491 - remove version max
-    @client_context.require_version_max(8, 0, -1)
     def test_drop_index(self):
         db = self.db
         db.test.drop_indexes()
@@ -346,7 +345,10 @@ class TestCollection(IntegrationTest):
         db.test.drop_index(name)
 
         # Drop it again.
-        with self.assertRaises(OperationFailure):
+        if client_context.version < Version(8, 3, -1):
+            with self.assertRaises(OperationFailure):
+                db.test.drop_index(name)
+        else:
             db.test.drop_index(name)
         self.assertEqual(len(db.test.index_information()), 2)
         self.assertIn("hello_1", db.test.index_information())
@@ -1305,7 +1307,7 @@ class TestCollection(IntegrationTest):
             self.assertIn(exc.code, (9, 10147, 16840, 17009))
             # Just check that we set the error document. Fields
             # vary by MongoDB version.
-            self.assertTrue(exc.details is not None)
+            self.assertIsNotNone(exc.details)
         else:
             self.fail("OperationFailure was not raised")
 
