@@ -22,18 +22,12 @@ import sys
 sys.path[0:0] = [""]
 
 from test import unittest
-from test.unified_format import generate_test_classes
+from test.unified_format import generate_test_classes, get_test_path
 
 _IS_SYNC = True
 
-# Location of JSON test specifications.
-if _IS_SYNC:
-    _TEST_PATH = os.path.join(pathlib.Path(__file__).resolve().parent, "crud", "unified")
-else:
-    _TEST_PATH = os.path.join(pathlib.Path(__file__).resolve().parent.parent, "crud", "unified")
-
 # Generate unified tests.
-globals().update(generate_test_classes(_TEST_PATH, module=__name__))
+globals().update(generate_test_classes(get_test_path("crud", "unified"), module=__name__))
 
 if __name__ == "__main__":
     unittest.main()
